Import Options
Figure size
Style sheet
System font
Font size
Chart Type
Line
Bar 1
Bar 2
Histogram
Box
Stack
Pie
Scatter
Hexbin
Contour
Image
Error Bar

X Value |
Y Value |
Z Value |
Bins |
X, Y Extent |
Origin |
Color Map | none
Chart Label |
Color | use color
Marker |
Line Style |
User Option |

Additional Options

Title |
X Label |
Y Label |
X Limit |
Y Limit |
Legend Title |
Legend Labels |
Legend Position |
Save Figure |